@@ -8,9 +8,9 @@ use Exporter qw(import);
 use File::chdir;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-05-20'; # DATE
+our $DATE = '2023-08-27'; # DATE
 our $DIST = 'App-ThisDist'; # DIST
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 our @EXPORT_OK = qw(this_dist this_mod);
 
@@ -171,7 +171,7 @@ sub this_dist {
             }
         }
 
-      FROM_REPO_NAME: {
+      __DISABLED__FROM_REPO_NAME: {
             last; # currently disabled
             log_debug "Using CPAN::Dist::FromRepoName to guess from dir name ...";
             require CPAN::Dist::FromRepoName;
@@ -184,6 +184,27 @@ sub this_dist {
             }
         }
 
+      FROM_ARCHIVE: {
+            require Filename::Perl::Release;
+            # if there is a single archive in the directory which looks like a
+            # perl release, use that.
+            my @files = grep { -f } glob "*";
+            my ($distfile, $dist, $ver);
+            for my $file (@files) {
+                my $res = Filename::Perl::Release::check_perl_release_filename(filename=>$file);
+                next unless $res;
+                last FROM_ARCHIVE if defined $dist;
+                $dist = $res->{distribution};
+                $ver  = $res->{version};
+                $distfile = $file;
+            }
+            last unless defined $dist;
+            $distname = $dist;
+            $distver  = $ver;
+            log_debug "Guessed distname=$distname from a single perl archive file in the directory ($distfile)";
+            last GUESS;
+        }
+
         log_debug "Can't guess distribution, giving up";
     }
     $extract_version ? "$distname ".(defined $distver ? $distver : "?") : $distname;
@@ -211,7 +232,7 @@ App::ThisDist - Print Perl {distribution,module,author,...} associated with curr
 
 =head1 VERSION
 
-This document describes version 0.019 of App::ThisDist (from Perl distribution App-ThisDist), released on 2023-05-20.
+This document describes version 0.020 of App::ThisDist (from Perl distribution App-ThisDist), released on 2023-08-27.
 
 =head1 DESCRIPTION
 
